"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.$delete = exports.post = exports.get = void 0;
const axios_1 = __importDefault(require("axios"));
const session_1 = require("./session");
const initialConfig = async (twoPi, validStatus) => {
    const config = {};
    if (validStatus) {
        config['validateStatus'] = validateStatus(validStatus);
    }
    if (twoPi.apiKey && twoPi.apiSecret) {
        const token = await (0, session_1.getValidToken)(twoPi);
        config['headers'] = (0, session_1.getAuthHeader)(token);
    }
    else {
        return {};
    }
    return config;
};
const validateStatus = (expected) => {
    return (status) => status < 400 || status === expected;
};
const get = async (twoPi, path, params) => {
    const config = await initialConfig(twoPi);
    return await axios_1.default.get(`${twoPi.endpoint}/${path}`, { ...config, params });
};
exports.get = get;
const post = async (twoPi, path, data, validStatus) => {
    const config = await initialConfig(twoPi, validStatus);
    return await axios_1.default.post(`${twoPi.endpoint}/${path}`, data, config);
};
exports.post = post;
const $delete = async (twoPi, path, params) => {
    const config = await initialConfig(twoPi);
    return await axios_1.default.delete(`${twoPi.endpoint}/${path}`, { ...config, params });
};
exports.$delete = $delete;
