"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAuthHeader = exports.getValidToken = void 0;
const axios_1 = __importDefault(require("axios"));
const routes_json_1 = __importDefault(require("./routes.json"));
const store = new Map();
const saveToken = (response) => {
    const { token, valid_until: validUntil } = response.data.data;
    store.set('token', { token, validUntil: new Date(validUntil) });
    return token;
};
const init = async (twoPi) => {
    const url = `${twoPi.endpoint}/${routes_json_1.default.sessionsPath}`;
    const response = await axios_1.default.post(url, {
        key: twoPi.apiKey,
        secret: twoPi.apiSecret
    });
    if (response.status === 200) {
        return saveToken(response);
    }
    else {
        throw new Error(`Authentication failed, response status was ${response.status} (expecting 200)`);
    }
};
const refresh = async (twoPi, token) => {
    const url = `${twoPi.endpoint}/${routes_json_1.default.sessionsPath}`;
    const config = { headers: (0, exports.getAuthHeader)(token) };
    const response = await axios_1.default.patch(url, {}, config);
    if (response.status === 200) {
        return saveToken(response);
    }
    else {
        throw new Error(`Authentication failed, response status was ${response.status} (expecting 200)`);
    }
};
const getValidToken = async (twoPi) => {
    const refreshOffset = 60 * 1000; // 1 minute
    const renewOffset = 10 * 1000; // 10 seconds
    const now = new Date().getTime();
    const { token, validUntil } = store.get('token') || {};
    const validTime = validUntil?.getTime() || 0;
    if (validTime - refreshOffset > now) {
        return token;
    }
    else if (validTime - renewOffset > now) {
        return await refresh(twoPi, token);
    }
    else {
        return await init(twoPi);
    }
};
exports.getValidToken = getValidToken;
const getAuthHeader = (token) => {
    return { 'Authorization': `Bearer ${token}` };
};
exports.getAuthHeader = getAuthHeader;
