"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteProposal = exports.getProposals = exports.Proposal = void 0;
const routes_json_1 = __importDefault(require("./helpers/routes.json"));
const request_1 = require("./helpers/request");
class Proposal {
    constructor({ id, status, transaction, createdAt }) {
        this.id = id;
        this.status = status;
        this.transaction = transaction;
        this.createdAt = createdAt;
    }
}
exports.Proposal = Proposal;
const params = (filter) => {
    const params = {};
    if (filter?.status) {
        params.status = filter.status;
    }
    return params;
};
const getProposals = async (twoPi, filter) => {
    const response = await (0, request_1.get)(twoPi, routes_json_1.default.proposalsPath, params(filter));
    return response.data.data.map((proposal) => {
        const { id, status, created_at: createdAt } = proposal;
        const { description, data, details } = proposal.transaction;
        const { chain_id: chainId, gas_price: gasPrice, rpc_url: rpcUrl } = proposal.transaction.provider || {};
        const transaction = {
            description,
            data,
            details,
            provider: { chainId, gasPrice, rpcUrl }
        };
        return new Proposal({
            id,
            status,
            transaction,
            createdAt: new Date(createdAt)
        });
    });
};
exports.getProposals = getProposals;
const deleteProposal = async (twoPi, proposal) => {
    const path = `${routes_json_1.default.proposalsPath}/${proposal.id}`;
    const response = await (0, request_1.$delete)(twoPi, path, {});
    return response.status === 204;
};
exports.deleteProposal = deleteProposal;
