"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAuthHeader = exports.getValidToken = void 0;
const axios_1 = __importDefault(require("axios"));
const store = new Map();
const init = async (twoPi) => {
    const response = await axios_1.default.post(`${twoPi.endpoint}/v1/sessions`, {
        key: twoPi.apiKey,
        secret: twoPi.apiSecret
    });
    if (response.status === 200) {
        const { token, valid_until: validUntil } = response.data.data;
        store.set('token', { token, validUntil: new Date(validUntil) });
        return token;
    }
    else {
        throw new Error(`Authentication failed, response status was ${response.status} (expecting 200)`);
    }
};
const refresh = async (twoPi, token) => {
    const config = {
        headers: (0, exports.getAuthHeader)(token)
    };
    const response = await axios_1.default.patch(`${twoPi.endpoint}/v1/sessions`, {}, config);
    if (response.status === 200) {
        const { token, valid_until: validUntil } = response.data.data;
        store.set('token', { token, validUntil: new Date(validUntil) });
        return token;
    }
    else {
        throw new Error(`Authentication failed, response status was ${response.status} (expecting 200)`);
    }
};
const getValidToken = async (twoPi) => {
    const refreshOffset = 60 * 1000; // 1 minute
    const renewOffset = 10 * 1000; // 10 seconds
    const now = new Date().getTime();
    const { token, validUntil } = store.get('token') || {};
    const validTime = validUntil?.getTime() || 0;
    if (validTime - refreshOffset > now) {
        return token;
    }
    else if (validTime - renewOffset > now) {
        return await refresh(twoPi, token);
    }
    else {
        return await init(twoPi);
    }
};
exports.getValidToken = getValidToken;
const getAuthHeader = (token) => {
    return { 'Authorization': `Bearer ${token}` };
};
exports.getAuthHeader = getAuthHeader;
