"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkApiKey = exports.getApiKey = void 0;
const https_1 = __importDefault(require("https"));
const http_1 = __importDefault(require("http"));
const readline_1 = __importDefault(require("readline"));
const process_1 = require("process");
const util_1 = __importDefault(require("util"));
const config_json_1 = __importDefault(require("../config.json"));
const endpoint_1 = require("./endpoint");
const getApiKey = async ({ key, secret }) => {
    if (key && secret) {
        return { key, secret };
    }
    else {
        const read = readline_1.default.createInterface({ input: process_1.stdin, output: process_1.stdout });
        const question = util_1.default.promisify(read.question).bind(read);
        const result = { key: '', secret: '' };
        const questions = {
            key: 'Please provide your API key: ',
            secret: 'Please provide your API secret: '
        };
        try {
            result.key = key || String(await question(questions.key));
            result.secret = secret || String(await question(questions.secret));
        }
        catch (error) {
            console.error(error);
        }
        finally {
            read.close();
        }
        return result;
    }
};
exports.getApiKey = getApiKey;
const request = (client, options, data) => {
    return new Promise((resolve, reject) => {
        const request = client.request(options);
        request.on('response', response => resolve(response));
        request.on('error', error => reject(error));
        request.write(data);
        request.end();
    });
};
const checkApiKey = async (apiKey, devMode) => {
    const data = new TextEncoder().encode(JSON.stringify(apiKey));
    const endpoint = (0, endpoint_1.getEndpointData)(devMode);
    const client = endpoint.protocol === 'https' ? https_1.default : http_1.default;
    const options = {
        hostname: endpoint.hostname,
        port: endpoint.port,
        path: config_json_1.default.sessionsPath,
        method: 'POST',
        headers: {
            'Content-Type': 'application/json',
            'Content-Length': data.length
        }
    };
    try {
        const response = await request(client, options, data);
        return response.statusCode === 200;
    }
    catch (error) {
        console.error(error);
        return false;
    }
};
exports.checkApiKey = checkApiKey;
