import { Wallet } from 'ethers';
import { TransactionsResponse } from './helpers/transaction';
import { Vault, Filter as VaultFilter } from './vaults';
import { Proposal, Filter as ProposalFilter } from './proposals';
declare type Constructor = {
    mnemonic?: string;
    path?: string;
    apiKey?: string;
    apiSecret?: string;
    endpoint?: string;
};
declare type Deposit = {
    amount: string;
    vaultIdentifier: 'mumbai_dai';
    unit: 'native' | 'wei' | undefined;
    referrer?: string;
};
declare type Withdraw = {
    amount: string;
    vaultIdentifier: 'mumbai_dai';
    unit: 'native' | 'wei' | undefined;
};
declare type Faucet = {
    network: 'polygon';
    address: string;
};
export default class TwoPi {
    readonly mnemonic?: string;
    readonly path?: string;
    readonly address?: string;
    readonly apiKey?: string;
    readonly apiSecret?: string;
    readonly endpoint: string;
    readonly wallet?: Wallet;
    constructor({ mnemonic, path, apiKey, apiSecret, endpoint }: Constructor);
    getVaults(filter: VaultFilter): Promise<Array<Vault>>;
    deposit({ amount, vaultIdentifier, unit, referrer }: Deposit): TransactionsResponse;
    withdraw({ amount, vaultIdentifier, unit }: Withdraw): TransactionsResponse;
    getProposals(filter: ProposalFilter): Promise<Array<Proposal>>;
    deleteProposal(proposal: Proposal): Promise<boolean>;
    faucet({ network, address }: Faucet): TransactionsResponse;
}
export {};
//# sourceMappingURL=twoPi.d.ts.map