"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ethers_1 = require("ethers");
const deposit_1 = require("./helpers/deposit");
const faucet_1 = require("./helpers/faucet");
const withdraw_1 = require("./helpers/withdraw");
const vaults_1 = require("./vaults");
const proposals_1 = require("./proposals");
class TwoPi {
    constructor({ mnemonic, path, apiKey, apiSecret, endpoint }) {
        this.mnemonic = mnemonic;
        this.path = path;
        this.wallet = mnemonic ? ethers_1.Wallet.fromMnemonic(mnemonic, path) : undefined;
        this.address = this.wallet?.address;
        this.apiKey = apiKey;
        this.apiSecret = apiSecret;
        this.endpoint = endpoint || 'https://api.2pi.network';
    }
    // Vault interactions
    async getVaults(filter) {
        return await (0, vaults_1.getVaults)(this, filter);
    }
    async deposit({ amount, vaultIdentifier, unit, referrer }) {
        return await (0, deposit_1.deposit)(this, {
            amount,
            vaultIdentifier,
            referrer,
            unit: unit || 'wei'
        });
    }
    async withdraw({ amount, vaultIdentifier, unit }) {
        return await (0, withdraw_1.withdraw)(this, {
            amount,
            vaultIdentifier,
            unit: unit || 'wei'
        });
    }
    // Proposal interactions
    async getProposals(filter) {
        return await (0, proposals_1.getProposals)(this, filter);
    }
    async deleteProposal(proposal) {
        return await (0, proposals_1.deleteProposal)(this, proposal);
    }
    // Faucet interactions
    async faucet({ network, address }) {
        return await (0, faucet_1.faucet)(this, { network, address });
    }
}
exports.default = TwoPi;
